@@ -1,11 +1,9 @@
-from django.core import validators
 from django.core.exceptions import ValidationError
 from django.db import models
 
 from controller.models.fields import NullableCharField, NullableTextField
 from controller.settings import PRIV_IPV6_PREFIX, PRIV_IPV4_PREFIX_DFLT, SLIVER_MAC_PREFIX_DFLT
 from controller.core.validators import validate_name, validate_prop_name, validate_net_iface_name
-from controller.utils.functional import cached
 from controller.utils.singletons.models import SingletonModel
 from pki import ca, Bob
 
