@@ -8,7 +8,7 @@ from django.contrib.admin.util import unquote
 from django.conf.urls import patterns, url
 from django.core.urlresolvers import reverse
 from django.http import HttpResponse, Http404
-from django.shortcuts import get_object_or_404, render_to_response
+from django.shortcuts import get_object_or_404
 from django.utils import timezone
 from django.utils.html import escape
 from django.utils.safestring import mark_safe
@@ -32,8 +32,10 @@ from slices.helpers import wrap_action
 from slices.models import Sliver, Slice
 
 from .actions import refresh, refresh_state, show_state
-from .filters import NodeStateListFilter, SliverStateListFilter, FirmwareVersionListFilter
-from .helpers import break_headers, break_lines, get_changes_data, sizeof_fmt
+from .filters import (NodeStateListFilter, SliverStateListFilter,
+    StateContentTypeFilter, FirmwareVersionListFilter)
+from .helpers import (break_headers, break_lines, extract_disk_available,
+    get_changes_data, sizeof_fmt)
 from .models import NodeSoftwareVersion, State, StateHistory
 from .settings import (STATE_NODE_SOFT_VERSION_URL, STATE_NODE_SOFT_VERSION_NAME,
         STATE_FLAPPING_CHANGES, STATE_FLAPPING_MINUTES)
@@ -199,6 +201,9 @@ class StateHistoryAdmin(PermissionModelAdmin):
 
 
 class StateAdmin(ChangeViewActions, PermissionModelAdmin):
+    list_display = ['id', 'content_type_link', 'current', 'content_object_link']
+    list_filter = (StateContentTypeFilter, 'value',)
+    ordering = ('content_type', 'object_id')
     fieldsets = (
         (None, {
             'fields': ('url_link', 'last_seen', 'last_contact',
@@ -274,9 +279,25 @@ class StateAdmin(ChangeViewActions, PermissionModelAdmin):
     
     def current(self, instance):
         state = display_current(instance)
-        return mark_safe('<a href="history">%s</a>' % (state))
+        url = reverse("admin:state_state_history", args=(instance.pk,))
+        return mark_safe('<a href="%s">%s</a>' % (url, state))
     display_current.short_description = 'current'
     
+    def content_object_link(self, instance):
+        ctype = instance.content_type
+        url_pattern = "admin:%s_%s_change" % (ctype.app_label, ctype.model)
+        url = reverse(url_pattern, args=(instance.object_id,))
+        return mark_safe('<a href="%s">%s</a>' % (url, instance.content_object))
+    content_object_link.admin_order_field = 'object_id'
+    content_object_link.short_description = 'object'
+    
+    def content_type_link(self, instance):
+        ctype = instance.content_type
+        url = reverse("admin:%s_%s_changelist" % (ctype.app_label, ctype.model))
+        return mark_safe('<a href="%s">%s</a>' % (url, instance.content_type))
+    content_type_link.admin_order_field = 'content_type'
+    content_type_link.short_description = 'object type'
+    
     def has_add_permission(self, request):
         """ Object states can not be manually created """
         return False
@@ -346,11 +367,17 @@ def disk_available(node):
         statejs = json.loads(node.state.data)
     except ValueError:
         return 'No data'
-    total = sizeof_fmt(statejs.get('disk_avail', 'N/A'))
-    slv_dflt = sizeof_fmt(statejs.get('disk_dflt_per_sliver', 'N/A'))
+    
+    disk = extract_disk_available(statejs)
+    # convert to human readable
+    unit = disk['unit']
+    total = sizeof_fmt(disk['total'], unit)
+    slv_dflt = sizeof_fmt(disk['slv_dflt'], unit)
+    
     return "%s (%s)" % (total, slv_dflt)
-disk_available.short_description = mark_safe('<span class="help-text" title="Disk '
-    'available reported by the node:\ntotal (default per sliver)">Disk available</span>')
+disk_available.short_description = mark_safe('<span class="help-text" '
+    'title="Disk available reported by the node:\ntotal (default per sliver)" '
+    'style="padding-left:0; padding-right:12px">Disk available</span>')
 
 
 
